DATA_DIR = "${prefix}/share"
LIB_DIR = "/opt/gnome2//lib"
VERSION = "2.15.2"
PACKAGE = "gnome-applets"
PYTHONDIR = "/opt/gnome2//lib/python2.4/site-packages"
